# frozen_string_literal: true

# Released under the MIT License.
# Copyright, 2019, by Samuel Williams.
# Copyright, 2022, by Gleb Sinyavskiy.

require 'rspec/core'

require_relative "files/version"
require_relative "files/leaks"
require_relative "files/buffer"
